@@ -1,7 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2019 Rumma & Ko Ltd
-#
-# License: BSD (see file COPYING for details)
+# Copyright 2014-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This package contains the code of the :ref:`xl`.
 
@@ -20,6 +19,6 @@ from lino_xl.setup_info import SETUP_INFO
 
 __version__ = SETUP_INFO['version']
 
-intersphinx_urls = dict(docs="http://xl.lino-framework.org")
-srcref_url = 'https://github.com/lino-framework/xl/blob/master/%s'
-doc_trees = ['docs']
+# intersphinx_urls = dict(docs="http://xl.lino-framework.org")
+srcref_url = 'https://gitlab.com/lino-framework/xl/blob/master/%s'
+# doc_trees = ['docs']
