@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
@@ -8,6 +8,7 @@ from django.conf import settings
 from lino.utils import format_date
 from lino.utils.media import TmpMediaFile
 from lino.core import actions
+from lino.core.roles import Expert
 from lino.api import dd, rt, _
 
 from .appy_renderer import AppyRenderer
@@ -30,6 +31,7 @@ class PrintTableAction(actions.Action):
                                   # for debugging templates
     combo_group = 'pdf'
     callable_from = 't'
+    required_roles = dd.login_required(Expert)
 
     # def is_callable_from(self, caller):
     #     return isinstance(caller, actions.ShowTable)
