@@ -28,10 +28,8 @@ class Plugin(Plugin):
         m.add_action('blogs.AllEntries')
         # m.add_action('blogs.AllTaggings')
 
-    def get_quicklinks(self, user):
-        yield dict(instance=user,
-            action=self.site.models.blogs.MyEntries.insert_action,
-            label=_("New blog entry"))
+    def setup_quicklinks(self, tb):
+        tb.add_action("blogs.MyEntries.insert", label=_("New blog entry"))
 
 
     # def get_dashboard_items(self, user):
