@@ -31,6 +31,8 @@ from lino.modlib.publisher.mixins import Publishable
 from lino_xl.lib.postings.mixins import Postable
 from lino_xl.lib.outbox.mixins import MailableType, Mailable
 from lino_xl.lib.contacts.mixins import ContactRelated
+from lino_xl.lib.google.mixins import GoogleCalendarEventSynchronized
+from lino_xl.lib.google.mixins import GoogleCalendarSynchronized
 from .choicelists import (
     DurationUnits, Recurrencies, Weekdays, AccessClasses, PlannerColumns, EventEvents, DisplayColors)
 
@@ -48,67 +50,69 @@ from .ui import ConflictingEvents
 
 DEMO_START_YEAR = 2013
 
-class CalendarType(object):
+if True:  # This will go away soon. It is not used anywhere.
 
-    def validate_calendar(self, cal):
-        pass
+    class CalendarType(object):
+
+        def validate_calendar(self, cal):
+            pass
 
 
-class LocalCalendar(CalendarType):
-    label = "Local Calendar"
+    class LocalCalendar(CalendarType):
+        label = "Local Calendar"
 
 
-class GoogleCalendar(CalendarType):
-    label = "Google Calendar"
+    class GoogleCalendar(CalendarType):
+        label = "Google Calendar"
 
-    def validate_calendar(self, cal):
-        if not cal.url_template:
-            cal.url_template = \
-                "https://%(username)s:%(password)s@www.google.com/calendar/dav/%(username)s/"
+        def validate_calendar(self, cal):
+            if not cal.url_template:
+                cal.url_template = \
+                    "https://%(username)s:%(password)s@www.google.com/calendar/dav/%(username)s/"
 
-CALENDAR_CHOICES = []
-CALENDAR_DICT = {}
+    CALENDAR_CHOICES = []
+    CALENDAR_DICT = {}
 
 
-def register_calendartype(name, instance):
-    CALENDAR_DICT[name] = instance
-    CALENDAR_CHOICES.append((name, instance.label))
+    def register_calendartype(name, instance):
+        CALENDAR_DICT[name] = instance
+        CALENDAR_CHOICES.append((name, instance.label))
 
-register_calendartype('local', LocalCalendar())
-register_calendartype('google', GoogleCalendar())
+    register_calendartype('local', LocalCalendar())
+    register_calendartype('google', GoogleCalendar())
 
 
-class RemoteCalendar(mixins.Sequenced):
+    class RemoteCalendar(mixins.Sequenced):
 
-    class Meta:
-        app_label = 'cal'
-        abstract = dd.is_abstract_model(__name__, 'RemoteCalendar')
-        verbose_name = _("Remote Calendar")
-        verbose_name_plural = _("Remote Calendars")
-        ordering = ['seqno']
+        class Meta:
+            app_label = 'cal'
+            abstract = dd.is_abstract_model(__name__, 'RemoteCalendar')
+            verbose_name = _("Remote Calendar")
+            verbose_name_plural = _("Remote Calendars")
+            ordering = ['seqno']
 
-    type = models.CharField(_("Type"), max_length=20,
-                            default='local',
-                            choices=CALENDAR_CHOICES)
-    url_template = models.CharField(_("URL template"),
+        type = models.CharField(_("Type"), max_length=20,
+                                default='local',
+                                choices=CALENDAR_CHOICES)
+        url_template = models.CharField(_("URL template"),
+                                        max_length=200, blank=True)  # ,null=True)
+        username = models.CharField(_("Username"),
                                     max_length=200, blank=True)  # ,null=True)
-    username = models.CharField(_("Username"),
-                                max_length=200, blank=True)  # ,null=True)
-    password = dd.PasswordField(_("Password"),
-                                max_length=200, blank=True)  # ,null=True)
-    readonly = models.BooleanField(_("read-only"), default=False)
+        password = dd.PasswordField(_("Password"),
+                                    max_length=200, blank=True)  # ,null=True)
+        readonly = models.BooleanField(_("read-only"), default=False)
 
-    def get_url(self):
-        if self.url_template:
-            return self.url_template % dict(
-                username=self.username,
-                password=self.password)
-        return ''
+        def get_url(self):
+            if self.url_template:
+                return self.url_template % dict(
+                    username=self.username,
+                    password=self.password)
+            return ''
 
-    def save(self, *args, **kw):
-        ct = CALENDAR_DICT.get(self.type)
-        ct.validate_calendar(self)
-        super(RemoteCalendar, self).save(*args, **kw)
+        def save(self, *args, **kw):
+            ct = CALENDAR_DICT.get(self.type)
+            ct.validate_calendar(self)
+            super(RemoteCalendar, self).save(*args, **kw)
 
 
 class Room(mixins.BabelNamed, ContactRelated, Colored):
@@ -204,7 +208,7 @@ def default_color():
     return n + 1
 
 
-class Calendar(mixins.BabelNamed):
+class Calendar(mixins.BabelNamed, GoogleCalendarSynchronized):
 
     COLOR_CHOICES = [i + 1 for i in range(32)]
 
@@ -222,14 +226,10 @@ class Calendar(mixins.BabelNamed):
     )
     # choices=COLOR_CHOICES)
 
-
-class Subscription(UserAuthored):
-
+class BaseSubscription(UserAuthored):
+    allow_cascaded_delete = ['user', 'calendar']
     class Meta:
-        app_label = 'cal'
-        abstract = dd.is_abstract_model(__name__, 'Subscription')
-        verbose_name = _("Subscription")
-        verbose_name_plural = _("Subscriptions")
+        abstract = True
         unique_together = ['user', 'calendar']
 
     manager_roles_required = dd.login_required(OfficeStaff)
@@ -243,6 +243,15 @@ class Subscription(UserAuthored):
         "initially be displayed as a hidden calendar."""))
 
 
+class Subscription(BaseSubscription):
+
+    class Meta:
+        app_label = 'cal'
+        abstract = dd.is_abstract_model(__name__, 'Subscription')
+        verbose_name = _("Subscription")
+        verbose_name_plural = _("Subscriptions")
+
+
 class Task(Component):
     class Meta:
         app_label = 'cal'
@@ -380,8 +389,10 @@ class ExtAllDayField(dd.VirtualField):
         return (obj.start_time is None)
 
 
+class Event(
+    Component, Ended, Assignable, TypedPrintable, Mailable, Postable,
+    Publishable, GoogleCalendarEventSynchronized):
 
-class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Publishable):
     class Meta:
         app_label = 'cal'
         abstract = dd.is_abstract_model(__name__, 'Event')
@@ -555,7 +566,9 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
     def full_clean(self, *args, **kw):
         super(Event, self).full_clean(*args, **kw)
         et = self.event_type
-        if et is not None and et.default_duration is not None:
+        if et is None:
+            return
+        if et.default_duration is not None:
             assert isinstance(et.default_duration, Duration)
             dt = self.get_datetime('start')
             if dt is not None and self.end_time is None:
@@ -564,7 +577,7 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
                 dt = self.get_datetime('end')
                 if dt is not None and self.start_time is None:
                     self.set_datetime('start', dt - et.default_duration)
-        if et and et.max_days == 1:
+        if et.max_days == 1:
             # avoid "Abandoning with 297 unsaved instances" when migrating data
             # that was created before the current rules
             self.end_date = None
@@ -737,7 +750,7 @@ class Event(Component, Ended, Assignable, TypedPrintable, Mailable, Postable, Pu
     def on_create(self, ar):
         if self.event_type is None:
             # print("20200513", ar.user)
-            self.event_type = ar.user.event_type or \
+            self.event_type = ar.get_user().event_type or \
                 settings.SITE.site_config.default_event_type
         self.start_date = self.start_date or settings.SITE.today()
         self.start_time = timezone.now().time()
@@ -1134,12 +1147,11 @@ dd.inject_field(settings.SITE.user_model,
             """The default access class for your calendar events and tasks.""")
                 ))
 dd.inject_field(settings.SITE.user_model,
-                'event_type',
-                dd.ForeignKey('cal.EventType',
-                                  blank=True, null=True,
-                                  verbose_name=_("Default Event Type"),
-        help_text=_("""The default event type for your calendar events.""")
-                ))
+    'event_type',
+    dd.ForeignKey('cal.EventType',
+    blank=True, null=True,
+    verbose_name=_("Calendar entry type"),
+    help_text=_("""The default type for your calendar entries.""")))
 
 dd.inject_field(
     'system.SiteConfig',
