@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -44,8 +44,6 @@ def weekname(date):
 
 
 class InsertEvent(dd.Action):
-    """Wrapper to insert an event in the daily view cal table.
-    Returns a js to eval which equates to running the insert window action for Events with the correct known values."""
     label = _("Create new Event")
     icon_name = 'add'  # if action rendered as toolbar button
     help_text = _("Create a new Event")
@@ -66,6 +64,13 @@ class DailyPlannerRows(dd.Table):
     required_roles = dd.login_required(OfficeStaff)
 
 class ParameterClone(dd.Actor):
+
+    # Mixin for actors that inherit parameters and params_layout from another
+    # table.
+    #
+    # The takeover must happen *after* the custom_layout_module has been loaded.
+    # So we override the class_init() method.
+
     abstract = True
     clone_from = 'cal.Events'
     # clone_from = None
@@ -83,13 +88,6 @@ class ParameterClone(dd.Actor):
         # cls.params_layout = rt.models.cal.Events.params_layout
         cls.params_layout = dd.plugins.calview.params_layout
 
-    # @classmethod
-    # def init_layouts(cls):
-    #     super(ParameterClone, cls).init_layouts()
-    #     if cls.abstract:
-    #         return
-    #     cls.params_layout = cls.clone_from.params_layout
-
     @classmethod
     def setup_parameters(cls, params):
         super(ParameterClone, cls).setup_parameters(params)
@@ -99,7 +97,6 @@ class ParameterClone(dd.Actor):
 
     @classmethod
     def get_data_elem(cls, name):
-        # return cls.clone_from.get_data_elem(name)
         e = super(ParameterClone, cls).get_data_elem(name)
         if e is None:
             e = cls.clone_from.get_data_elem(name)
@@ -117,76 +114,6 @@ class ParameterClone(dd.Actor):
         kwargs = super(ParameterClone, cls).param_defaults(ar, **kwargs)
         return cls.clone_from.param_defaults(ar, **kwargs)
 
-    # @classmethod
-    # def get_calendar_entries(cls, ar, obj):
-    #     qs = cls.clone_from.get_request_queryset(ar)
-    #     if obj is not None:
-    #         qs = obj.get_my_plannable_entries(qs, ar)
-    #     # qs = Event.objects.all()
-    #     # qs = Event.calendar_param_filter(qs, ar.param_values)
-    #     # print("20200430", ar.master_instance, obj, qs.query)
-    #     return qs
-
-
-class EventsParameters(ParameterClone):
-    """
-
-    Mixin for actors that inherit parameters and params_layout from the
-    cal.Events table as defined by the application.
-
-    The takeover must happen *after* the custom_layout_module has been loaded.
-    So we override the class_init() method.
-
-    """
-    abstract = True
-    # clone_from = 'cal.Events'
-    # clone_from = 'cal.EntriesByDay'
-
-    # @classmethod
-    # def setup_parameters(cls, params):
-    #     super(EventsParameters, cls).setup_parameters(params)
-    #     rt.models.cal.Events.setup_parameters(params)
-    #
-    # @classmethod
-    # def get_simple_parameters(cls):
-    #     for p in super(EventsParameters, cls).get_simple_parameters():
-    #         yield p
-    #     for p in rt.models.cal.Events.get_simple_parameters():
-    #         yield p
-    #
-    # @classmethod
-    # def param_defaults(self, ar, **kwargs):
-    #     kwargs = super(EventsParameters, cls).param_defaults(ar, **kwargs)
-    #     return rt.models.cal.Events.param_defaults(ar, **kwargs)
-    #
-    # @classmethod
-    # def get_calendar_entries(cls, ar, obj):
-    #     qs = rt.models.cal.Events.get_request_queryset(ar)
-    #     if obj is not None:
-    #         qs = obj.get_my_plannable_entries(qs, ar)
-    #     # qs = Event.objects.all()
-    #     # qs = Event.calendar_param_filter(qs, ar.param_values)
-    #     # print("20200430", ar.master_instance, obj, qs.query)
-    #     return qs
-    #
-
-
-# class TableWithHeaderRow(dd.Table):
-#     """
-#
-#     Mixin for tables that insert a virtual header row where all-day events are
-#     shown.  Used in daily and weekly view but not in monthly view.
-#
-#     """
-#     abstract = True
-#
-#     @classmethod
-#     def get_request_queryset(cls, ar):
-#     # def get_data_rows(cls, ar):
-#         yield cls.model.HEADER_ROW
-#         for obj in super(TableWithHeaderRow, cls).get_request_queryset(ar):
-#             yield obj
-
 
 class Day(TableRow):
 
@@ -233,7 +160,6 @@ class Day(TableRow):
             # params[k] = dbfield2params_field(Event._meta.get_field(k))
 
 
-
 class DaysTable(dd.VirtualTable):
     abstract = True
     model = 'calview.Day'
@@ -287,14 +213,6 @@ class DaysTable(dd.VirtualTable):
 
 
 class DayNavigator(DaysTable):
-    """
-
-    Base class for the three calendar views, but also used for independent
-    tables like working.WorkedHours. A virtual table whose rows are calview.Day
-    instances.  Subclasses must set navigation_mode.
-
-    """
-
     # every row is a Day instance. Note that Day can be overridden.
 
     abstract = True
@@ -347,14 +265,6 @@ class DayNavigator(DaysTable):
         return cls.day_number.return_type
 
 class CalendarView(DayNavigator):
-    """
-    A calendar view opens in detail view by default, the grid view is useless.
-
-    The detail of a calendar view usually has a calendar navigator panel at the
-    left side.  The right side varies, but it usually shows at least one slave
-    table which is usually a subclass of DaySlave.
-
-    """
     abstract = True
     use_detail_param_panel = True
     # plannable_model = None  # must be set for concrete subclasses
@@ -480,13 +390,6 @@ class CalendarView(DayNavigator):
 
 
 class DaySlave(AbstractTable):
-
-    """
-    Table mixin for slave tables of tables on calview.Day.
-
-    Used by both database and virtual tables.
-    """
-
     abstract = True
     editable = False
     # hide_top_toolbar = True # no selections no toolbar
@@ -646,8 +549,8 @@ class DailySlaveBase(DaySlave, VentilatedColumns):
 
 class WeeklySlaveBase(DaySlave, VentilatedColumns):
 
-    """subclassed by WeeklySlave, but also in Presto where we define a custom
-    weekly Slave as a class WorkersByWeek(Workers, WeeklySlaveBase)"""
+    # subclassed by WeeklySlave, but also in Presto where we define a custom
+    # weekly Slave as a class WorkersByWeek(Workers, WeeklySlaveBase)
 
     abstract = True
     # title = _("Weekly planner")
@@ -770,8 +673,7 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
         return dd.VirtualField(dd.HtmlBox(wd.text), func)
 
 
-class DailyPlanner(EventsParameters, DailySlaveBase, DailyPlannerRows):
-# 20200430 class DailyPlanner(DailySlaveBase, DailyPlannerRows):
+class DailyPlanner(ParameterClone, DailySlaveBase, DailyPlannerRows):
     # display_mode = "html"
     navigation_mode = 'day'
 
@@ -780,8 +682,7 @@ class DailySlave(DailyPlanner):
     @classmethod
     def get_actor_label(self): return None
 
-class WeeklySlave(EventsParameters, WeeklySlaveBase, DailyPlannerRows):
-# 20200430 class WeeklySlave(WeeklySlaveBase, DailyPlannerRows):
+class WeeklySlave(ParameterClone, WeeklySlaveBase, DailyPlannerRows):
     # model = 'calview.DailyPlannerRow'
     # required_roles = dd.login_required(OfficeStaff)
     # display_mode = "html"
@@ -798,8 +699,7 @@ class WeeklySlave(EventsParameters, WeeklySlaveBase, DailyPlannerRows):
     #     kw.update(user=ar.get_user())  # TODO: not sure whether we want this
     #     return kw
 
-class MonthlySlave(EventsParameters, MonthlySlaveBase, DaysTable):
-# 20200430 class MonthlySlave(MonthlySlaveBase, DaysTable):
+class MonthlySlave(ParameterClone, MonthlySlaveBase, DaysTable):
     # required_roles = dd.login_required(OfficeStaff)
     with_header_row = False
     navigation_mode = "month"
@@ -872,21 +772,18 @@ class MonthDetail(dd.DetailLayout):
     main = "body"
     body = "navigation_panel:15 calview.MonthlySlave:85"
 
-class DailyView(EventsParameters, CalendarView):
-# 20200430 class DailyView(CalendarView):
+class DailyView(ParameterClone, CalendarView):
     label = _("Daily view")
     detail_layout = 'calview.DayDetail'
     navigation_mode = "day"
     insert_event = InsertEvent()
 
-class WeeklyView(EventsParameters, CalendarView):
-# 20200430 class WeeklyView(CalendarView):
+class WeeklyView(ParameterClone, CalendarView):
     label = _("Weekly view")
     detail_layout = 'calview.WeekDetail'
     navigation_mode = "week"
 
-class MonthlyView(EventsParameters, CalendarView):
-# 20200430 class MonthlyView(CalendarView):
+class MonthlyView(ParameterClone, CalendarView):
     label = _("Monthly view")
     detail_layout = 'calview.MonthDetail'
     navigation_mode = "month"
