@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino_xl.lib.ledger.utils import ZERO, ONE
@@ -624,9 +624,9 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
         #~ return _("Confirmation not implemented")
 
     def get_guest_role(self):
-        # voga overrides this
         if self.course.line:
-            return self.course.line.guest_role
+            return self.course.line.guest_role or settings.SITE.site_config.pupil_guestrole
+        return settings.SITE.pupil_guestrole
 
     def make_guest_for(self, event):
         if not self.state.uses_a_place:
@@ -687,6 +687,15 @@ dd.update_field(
 
 dd.update_field(Enrolment, 'course', blank=True)
 
+
+dd.inject_field('system.SiteConfig', 'pupil_guestrole',
+    dd.ForeignKey('cal.GuestRole',
+        verbose_name=_("Default guest role for participants"),
+        related_name='pupil_guestroles',
+        blank=True, null=True))
+
+
+
 @dd.receiver(dd.post_startup)
 def setup_memo_commands(sender=None, **kwargs):
     # See :doc:`/specs/memo`
