@@ -18,7 +18,7 @@ def objects():
     Worker = dd.plugins.ledger.worker_model
     if Worker is not None:
         kwargs = {}
-        kwargs['worker'] = Worker.objects.get(first_name="Robin")
+        kwargs['worker'] = Worker.objects.get(first_name="Robin", last_name="Dubois")
         kwargs['ref'] = "robin"
         kwargs = dd.str2kw('name', _("Cash Robin"), **kwargs)
         yield PaymentTerm(**kwargs)
